# edwh_web2py_effdted_prio_grid

[![PyPI - Version](https://img.shields.io/pypi/v/edwh-web2py-effdted-prio-grid.svg)](https://pypi.org/project/edwh-web2py-effdted-prio-grid)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/edwh-web2py-effdted-prio-grid.svg)](https://pypi.org/project/edwh-web2py-effdted-prio-grid)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install edwh-web2py-effdted-prio-grid
```

## Usage
```python
from edwh_web2py_effdted_prio_grid import effective_dated_grid

effective_dated_grid(db.organisations)

```

## License

`edwh-web2py-effdted-prio-grid` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
